@@ -1,4 +1,4 @@
-package Perinci::Sub::Wrapper::Property::retry;
+package Perinci::Sub::Property::retry;
 
 use 5.010;
 use strict;
@@ -6,7 +6,7 @@ use warnings;
 
 use Perinci::Util qw(declare_property);
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 declare_property(
     name => 'retry',
@@ -117,11 +117,11 @@ __END__
 
 =head1 NAME
 
-Perinci::Sub::Wrapper::Property::retry - Specify automatic retry
+Perinci::Sub::Property::retry - Specify automatic retry
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
